==> nmrium-0.50.1.tgz: package/lib/component/main/NMRiumStateProvider.js <==
import { jsx as _jsx } from "react/jsx-runtime";
import { readNMRiumObject } from 'nmr-load-save';
import { useCallback, useEffect, useReducer, useRef } from 'react';
import { toJSON } from '../../data/SpectraManager';
import { ChartDataProvider } from '../context/ChartContext';
import { DispatchProvider } from '../context/DispatchContext';
import { useLogger } from '../context/LoggerContext';
import { usePreferences } from '../context/PreferencesContext';
import checkActionType from '../reducer/IgnoreActions';
import { spectrumReducer, initialState, initState } from '../reducer/Reducer';
const defaultData = {
    spectra: [],
};
export default function NMRiumStateProvider(props) {
    const { children, onChange, nmriumData = defaultData } = props;
    const { logger } = useLogger();
    const preferencesState = usePreferences();
    const [state, dispatchRaw] = useReducer(spectrumReducer, initialState, initState);
    const dispatch = useCallback((action) => {
        logger.trace({ action }, `Dispatch main reducer action: ${action.type}`);
        dispatchRaw(action);
    }, [logger]);
    const { source, data: spectraData, molecules, correlations, actionType, view, } = state;
    const stateRef = useRef();
    const handleChange = useRef(onChange);
    useEffect(() => {
        handleChange.current = onChange;
    }, [onChange]);
    useEffect(() => {
        const { workspace, workspaces = {} } = preferencesState;
        stateRef.current = toJSON({ data: spectraData, molecules, correlations, source, view, actionType }, { current: workspaces[workspace.current] }, { serialize: false, exportTarget: 'onChange' });
    }, [
        actionType,
        correlations,
        molecules,
        preferencesState,
        source,
        spectraData,
        view,
    ]);
    useEffect(() => {
        // trigger onChange callback if data object changed
        if (checkActionType(actionType)) {
            handleChange.current?.(stateRef.current, 'data');
        }
    }, [actionType, correlations, molecules, source, spectraData]);
    useEffect(() => {
        // trigger onChange callback if view object changed
        handleChange.current?.(stateRef.current, 'view');
    }, [view]);
    useEffect(() => {
        // trigger onChange callback if settings changed
        handleChange.current?.(stateRef.current, 'settings');
    }, [preferencesState]);
    useEffect(() => {
        dispatch({
            type: 'SET_LOADING_FLAG',
            payload: { isLoading: true },
        });
        if (nmriumData) {
            void readNMRiumObject(nmriumData)
                .then((nmriumState) => {
                dispatch({ type: 'INITIATE', payload: { nmriumState } });
            })
                .catch((error) => {
                dispatch({ type: 'SET_LOADING_FLAG', payload: { isLoading: false } });
                // eslint-disable-next-line no-alert
                alert(error.message);
                reportError(error);
            });
        }
    }, [nmriumData, dispatch]);
    return (_jsx(DispatchProvider, { value: dispatch, children: _jsx(ChartDataProvider, { value: state, children: children }) }));
}

==> nmrium-0.53.0.tgz: package/lib/component/main/NMRiumStateProvider.js <==
import { jsx as _jsx } from "react/jsx-runtime";
import { readNMRiumObject } from 'nmr-load-save';
import { useCallback, useEffect, useReducer, useRef } from 'react';
import { toJSON } from '../../data/SpectraManager';
import { ChartDataProvider } from '../context/ChartContext';
import { DispatchProvider } from '../context/DispatchContext';
import { useLogger } from '../context/LoggerContext';
import { usePreferences } from '../context/PreferencesContext';
import checkActionType from '../reducer/IgnoreActions';
import { spectrumReducer, initialState, initState } from '../reducer/Reducer';
const defaultData = {
    spectra: [],
};
export default function NMRiumStateProvider(props) {
    const { children, onChange, nmriumData = defaultData } = props;
    const { logger } = useLogger();
    const preferencesState = usePreferences();
    const [state, dispatchRaw] = useReducer(spectrumReducer, initialState, initState);
    const dispatch = useCallback((action) => {
        logger.trace({ action }, `Dispatch main reducer action: ${action.type}`);
        dispatchRaw(action);
    }, [logger]);
    const { source, data: spectraData, molecules, correlations, actionType, view, } = state;
    const stateRef = useRef();
    const handleChange = useRef(onChange);
    useEffect(() => {
        handleChange.current = onChange;
    }, [onChange]);
    useEffect(() => {
        const { workspace, workspaces = {} } = preferencesState;
        stateRef.current = toJSON({ data: spectraData, molecules, correlations, source, view, actionType }, { current: workspaces[workspace.current] }, { serialize: false, exportTarget: 'onChange' });
    }, [
        actionType,
        correlations,
        molecules,
        preferencesState,
        source,
        spectraData,
        view,
    ]);
    useEffect(() => {
        // trigger onChange callback if data object changed
        if (checkActionType(actionType)) {
            handleChange.current?.(stateRef.current, 'data');
        }
    }, [actionType, correlations, molecules, source, spectraData]);
    useEffect(() => {
        // trigger onChange callback if view object changed
        handleChange.current?.(stateRef.current, 'view');
    }, [view]);
    useEffect(() => {
        // trigger onChange callback if settings changed
        handleChange.current?.(stateRef.current, 'settings');
    }, [preferencesState]);
    useEffect(() => {
        dispatch({
            type: 'SET_LOADING_FLAG',
            payload: { isLoading: true },
        });
        if (nmriumData) {
            void readNMRiumObject(nmriumData)
                .then((nmriumState) => {
                dispatch({ type: 'INITIATE', payload: { nmriumState } });
            })
                .catch((error) => {
                dispatch({ type: 'SET_LOADING_FLAG', payload: { isLoading: false } });
                // eslint-disable-next-line no-alert
                window.alert(error.message);
                reportError(error);
            });
        }
    }, [nmriumData, dispatch]);
    return (_jsx(DispatchProvider, { value: dispatch, children: _jsx(ChartDataProvider, { value: state, children: children }) }));
}
